C
C Version 1.02 (original) routines replaced by version 1.03 (Bartak extensions)
C routines.
C Messages in Czechoslovak translated to english.
C Comments and version number added to each routine.
C Bartak's extended ranges identified.
C Pressure ranges in extended routines standardized to 0.002-21.5 MPa.
C Temperature ranges in extended routines standardized to 18.0-373.0 C
C In the interest of speed RETURN statement added after each IF test.
C In the interest of code maintenance pressure range checks in some
C routines made in terms of the variables Pmin and Pmax.
C
C   Robert J Wilson.                                Febuary 1991
C   EACS - Engineering & Computing Services
C   82 Rayne Avenue
C   Oakville, Ontario
C   L6H 1C2, Canada
C   Tel:(416)844-7488
C
**************************************************************************
*      Extensions to the saturated H2O property functions in the
*      low pressure range - pressures down to 0.002 MPa.
*      Extensions are provided for the following saturation properties:
*      DF,DG,DHFDP,DHGDP,DPDT,DSFDP,DSGDP,DTDP,DVFDP,DVGDP,
*      HF,HG,PSAT,SF,SG,TSAT,VF,VG
*
*      J. Bartak & M. Stastny
*      National Research Institute for Machine Design
*      190 11  Prague 9 - Bechovice
*      Czechoslovakia
*      Phone: 741351, ext. 2780
*
*      March 1990
*

*************************************************************************
*      H2O property functions based on:
*          L. Harr, J. Gallagher and G. Kell, "NBS/NRC Steam Tables,
*          Thermodynamic and Transport Properties and Computer Programs 
*          for Vapor and Liquid States of Water in SI Units", 
*          Hemisphere Publishing Corp., McGraw-Hill International Book
*          Company, 1984, ISBN 0-89116-354-9.
*
*      These functions are low-order fits that are fast running and
*      reasonably accurate (usually < 0.1% error). For more information
*      refer to the following publications:
*
*
*      Please feel free to distribute copies of these functions since the
*      general idea is to promote the free exchange of useful code.
*      Please DO NOT distribute altered copies; the world is confusing 
*      enough as it is. I would appreciate being informed of any errors,
*      ommisions, comments, etc.
*              
*          Wm. J. Garland
*          Associate Professor
*          Department of Engineering Physics
*          McMaster University
*          1280 Main St. W.
*          Hamilton, Ontario   
*          Canada    L8S 4M1
*          Ph: (416) 525-9140 ext. 4925           
*
*************************************************************************
*
* Saturation properties based on reference 1 (Garland and Hoskins)
*
* Subcooled and superheated properties based on reference 2 (Garland and 
* Hand)
*         SAT means saturated
*         SUB means subcooled
*         SUP means superheated
*

*************************************************************************
       FUNCTION CPF(P)
C Ver. 1.02
****   This function calculates the specific heat of light water 
****   for a given pressure. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
       IF (P.LT.0.03) THEN
             CPF=0.247763* 0.03**0.5704026 +4.150
           ERRH2O=' CPF: PRESSURE LESS THAN 0.03 MPa'
           RETURN
       ELSEIF (P.GT.21.5) THEN
             CPF= 4.6844786E-6*EXP(0.7396875*21.5)+10.020
           ERRH2O=' CPF: PRESSURE GREATER THAN 21.5 MPa'
             RETURN
         ELSEIF (P.GE.0.030.AND.P.LE.0.671) THEN
             CPF=0.247763* P**0.5704026 +4.150
             RETURN
         ELSEIF (P.GT.0.671.AND.P.LE.2.606) THEN
             CPF=0.1795305* P**0.8967323 +4.223
             RETURN
         ELSEIF (P.GT.2.606.AND.P.LE.6.489) THEN
             CPF=0.09359843* P**1.239114 +4.340
             RETURN
         ELSEIF (P.GT.6.489.AND.P.LE.11.009) THEN
             CPF=0.01068888* P**2.11376 +4.740
             RETURN
         ELSEIF (P.GT.11.009.AND.P.LE.14.946) THEN
             CPF=1.333058E-4* P**3.707294 +5.480
             RETURN
         ELSEIF (P.GT.14.946.AND.P.LE.18.079) THEN
             CPF=6.635658E-3* (P -10.0)**3.223323+7.350
             RETURN
         ELSE
             CPF= 4.6844786E-6*EXP(0.7396875*P)+10.020
             RETURN
       ENDIF
       END

       FUNCTION CPFSUB(P,T)
C Ver. 1.02
****   This function calculates the heat capacity of light water 
****   in the subcooled liquid phase. 
       CHARACTER ERRH2O*70
       COMMON/ERRORS/ERRH2O
       PS=PSAT(T)
       PP=P
       TT=T
       IF (P.LT.PS) THEN
           PP=PS
           ERRH2O=' CPFSUB: PRESSURE LESS THAN SATURATION'
       ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' CPFSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.89.96) THEN
           TT=89.96
           ERRH2O=' CPFSUB: TEMPERATURE LESS THAN 89.96 deg C'
       ELSEIF (T.GT.357.03) THEN
           TT=357.03
           ERRH2O=' CPFSUB: TEMPERATURE GREATER THAN 357.03 deg C'
       ENDIF
       CPFSUB = CPF(PS) + (0.0018-76./(364.-TT)**1.8)*(PP-PS)
       RETURN
       END

       FUNCTION CPG(P)
C Ver. 1.02
****   This function calculates the specific heat of light water 
****   in the vapour phase for a given pressure. 
       CHARACTER ERRH2O*70
       COMMON/ERRORS/ERRH2O
       IF (P.LT.0.05) THEN
             CPG=0.6471635* (0.05-0.006)**0.6400569 +1.90
           ERRH2O=' CPG: PRESSURE LESS THAN 0.05 MPa'
           RETURN
       ELSEIF (P.GT.20.4) THEN
             CPG= 6.5162612E-6*EXP(0.7562118*20.4)+17.10
           ERRH2O=' CPG: PRESSURE GREATER THAN 20.4 MPa'
             RETURN
         ELSEIF (P.GE.0.050.AND.P.LE.0.599) THEN
             CPG=0.6471635* (P-0.006)**0.6400569 +1.90
             RETURN
         ELSEIF (P.GT.0.599.AND.P.LE.2.391) THEN
             CPG=0.5560633* P**0.8197355 +2.00
             RETURN
         ELSEIF (P.GT.2.391.AND.P.LE.5.661) THEN
             CPG=0.3187082* P**1.110271 +2.3
             RETURN
         ELSEIF (P.GT.5.661.AND.P.LE.9.458) THEN
             CPG=0.064275995* P**1.766106 +3.12
             RETURN
         ELSEIF (P.GT.9.458.AND.P.LE.12.900) THEN
             CPG=3.8011048E-3* P**2.816897 +4.40
             RETURN
         ELSEIF (P.GT.12.900.AND.P.LE.16.309) THEN
             CPG=0.1876175* EXP(0.2466925*P)+5.00
             RETURN
         ELSEIF (P.GT.16.309.AND.P.LE.18.743) THEN
             CPG=7.62075E-3* EXP(P*0.4117289)+9.20
             RETURN
         ELSE
             CPG= 6.5162612E-6*EXP(0.7562118*P)+17.10
             RETURN
       ENDIF
       END
       
       FUNCTION CPGSUP(P,T)
C Ver. 1.02
****   This function calculates the heat capacity of light water 
****   in the superheated gaseous phase. 
       CHARACTER ERRH2O*70
       COMMON/ERRORS/ERRH2O
       TS=TSAT(P)
       PP=P
       TT=T
       IF (P.LT.0.07) THEN
           PP=0.07
           ERRH2O=' CPGSUB: PRESSURE LESS THAN 0.07 MPa'
       ELSEIF (P.GT.14.) THEN
           PP=14.
           ERRH2O=' CPGSUB: PRESSURE GREATER THAN 14 MPa'
       ELSEIF (T.LT.TS) THEN
           TT=TS
           ERRH2O=' CPGSUB: TEMPERATURE LESS THAN SATURATION'
       ELSEIF (T.GT.400.) THEN
           TT=400.
           ERRH2O=' CPGSUB: TEMPERATURE GREATER THAN 400. deg C'
       ENDIF
       CPGSUP = CPG(P) -(0.011*PP/(0.00014*(TT+8)**2-PP)**1.5+
     *        1.5E-8*(655.-TT)**2.1)*PP*(TT-TS) 
      RETURN
      END

      FUNCTION DF(P)
C Ver. 1.03
****   This function calculates the density of light water
****   in the liquid phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      Pmin =  0.002
      Pmax = 21.5
C Check upper and lower pressure limits
      IF (P .LT. Pmin) THEN
           DF=1./(1.9118E-4* Pmin** 0.546472 + 0.0009947)
             ERRH2O=' DF: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GT. Pmax) THEN
              DF=1./(4.1035988E-24* Pmax**15.03329 +0.00189)
           ERRH2O=' DF: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
C Pressure was neither Pmin or Pmax - continue
      ELSEIF (P.GE.0.002 .AND. P.LT.0.01468) THEN
           DF=1./ (1.9118E-4 * P**0.546472 + 0.0009947)
           RETURN
      ELSEIF (P.GE.0.01468 .AND. P.LT.0.275) THEN
           DF=1./ (1.380934E-4 * P**0.388715 + 0.000987)
           RETURN
      ELSEIF (P.GE.0.275.AND.P.LE.1.0) THEN
           DF=1./(1.2746977E-4* P**0.4644339 +0.001)
           RETURN
      ELSEIF (P.GT.1.0.AND.P.LE.3.88) THEN
             DF=1./(1.0476071E-4* P**0.5651090 +0.001022)
           RETURN
      ELSEIF (P.GT.3.88.AND.P.LE.8.84) THEN
             DF=1./(3.2836717E-5* P +1.12174735E-3)
           RETURN
      ELSEIF (P.GT.8.84.AND.P.LE.14.463) THEN
             DF=1./(3.3551046E-4 * EXP(0.058403566 *P) +0.00085)
           RETURN
      ELSEIF (P.GT.14.463.AND.P.LT.18.052) THEN
             DF= 1./(3.1014626E-8* P**3.284754 +0.00143)
           RETURN
      ELSEIF (P.GE.18.052.AND.P.LT.20.204) THEN
             DF= 1./(1.5490787E-11* P**5.7205 +0.001605)
           RETURN
      ELSE
             DF= 1./(4.1035988E-24* P**15.03329 +0.00189)
      ENDIF
C      ERRH2O=' DF: DENSITY OF SUBCOOLED LIQUID NOT EVALUATED'
      RETURN
      END




       FUNCTION DFSUB(P,T)
C Ver. 1.02
****   This function calculates the density of light water 
****   in the subcooled liquid phase. 
       CHARACTER ERRH2O*70
       COMMON/ERRORS/ERRH2O
       PS=PSAT(T)
       PP=P
       TT=T
       IF (P.LT.PS) THEN
           PP=PS
           ERRH2O=' DFSUB: PRESSURE LESS THAN SATURATION'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' DFSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.91.79) THEN
           TT=91.79
           ERRH2O=' DFSUB: TEMPERATURE LESS THAN 91.79 deg C'
       ELSEIF (T.GT.357.03) THEN
           TT=357.03
           ERRH2O=' DFSUB: TEMPERATURE GREATER THAN 357.03 deg C'
      ENDIF
      DFSUB = DF(PS) + ( 170.0 / (375.0-TT) - 0.2) * ( PP-PS )
      RETURN
      END

      FUNCTION DG(P)
C Ver. 1.03
****   This function calculates the density of light water
****   in the gas phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      Pmin =  0.002
      Pmax = 21.5
      IF (P .LT. Pmin) THEN
           DG= 5.0981616 * Pmin**0.936226 - 0.00025
           ERRH2O=' DG: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GT. Pmax) THEN
              DG= 3.558734E-16* Pmax**13.03774 +138.0
           ERRH2O=' DG: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.2139) THEN
           DG= 5.0981616 * P**0.936226 - 0.00025
           RETURN
      ELSEIF (P.GE.0.2139.AND.P.LT.1.112) THEN
           DG= 5.126076* P**0.9475862 +0.012
           RETURN
      ELSEIF (P.GE.1.112.AND.P.LT.3.932) THEN
             DG= 4.630832* P**1.038819 +0.52
           RETURN
      ELSEIF (P.GE.3.932.AND.P.LT.8.996) THEN
             DG= 2.868721* P**1.252148 +3.80
           RETURN
      ELSEIF (P.GE.8.996.AND.P.LT.14.628) THEN
             DG= 0.5497653* P**1.831182 +18.111
           RETURN
      ELSEIF (P.GE.14.628.AND.P.LE.18.21) THEN
             DG= 8.5791582E-3* P**3.176484 +50.0
           RETURN
      ELSEIF (P.GT.18.21.AND.P.LE.20.253) THEN
             DG= 3.5587113E-6* P**5.660939 +88.0
           RETURN
      ELSE
             DG= 3.558734E-16* P**13.03774 +138.0
      ENDIF
      RETURN
      END

       FUNCTION DGSUP(P,T)
C Ver. 1.02
****   This function calculates the density of light water 
****   in the superheated gaseous phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      TS=TSAT(P)
      PP=P
      TT=T
       IF (P.LT.0.085) THEN
           PP=0.085
           ERRH2O=' DGSUP: PRESSURE LESS THAN 0.085 MPa'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' DGSUP: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.TS) THEN
           TT=TS
           ERRH2O=' DGSUP: TEMPERATURE LESS THAN SATURATION'
       ELSEIF (T.GT.450.) THEN
           TT=450.
           ERRH2O=' DGSUP: TEMPERATURE GREATER THAN 450. deg C'
      ENDIF
      DGSUP = (VG(PP)+(0.000466/PP-(0.12 /(TT+100) - 0.00106 )*PP**0.1
     *        / SQRT ( 1.96E-08 * (TT+8. )**4 -PP*PP)) * (TT-TS))**(-1)
      RETURN
      END

      FUNCTION DHFDP(P)
C Ver. 1.03
****   This function calculates the derivative with respect to
****   pressure of the specific enthalpy of light water in the
****   liquid phase at saturation for a given saturation pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      Pmin =  0.002
      Pmax = 21.5
      IF (P .LT. Pmin) THEN
           DHFDP= 1128.777*0.135196* 0.002**(0.135196 -1.0)
           ERRH2O=' DHFDP: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GT. Pmax) THEN
              DHFDP= 9.1417257E-14* 11.47287* Pmax**10.47287
              ERRH2O=' DHFDP: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF(P.GE.0.002 .AND. P.LT.0.0173) THEN
           DHFDP=1128.777 * 0.135196 * P**(0.135196-1.0)
           RETURN
      ELSEIF(P.GE.0.0173 .AND. P.LT.0.1028) THEN
           DHFDP=1050.7085 * 0.161797 * P**(0.161797-1.0)
           RETURN
      ELSEIF (P.GE.0.1028.AND.P.LT.0.942) THEN
           DHFDP= 912.1779*0.2061637* P**(0.2061637 -1.0)
           RETURN
      ELSEIF (P.GE.0.942.AND.P.LT.4.02) THEN
             DHFDP= 638.0621*0.2963192* P**(0.2963192 -1.0)
           RETURN
      ELSEIF (P.GE.4.02.AND.P.LT.9.964) THEN
             DHFDP= 373.7665*0.4235532* P**(0.4235532 -1.0)
           RETURN
      ELSEIF (P.GE.9.964.AND.P.LT.16.673) THEN
             DHFDP= 75.38673*0.8282384* P**(0.8282384 -1.0)
           RETURN
      ELSEIF (P.GE.16.673.AND.P.LT.20.396) THEN
             DHFDP= 0.1150827* 2.711412* P**1.711412
           RETURN
      ELSE
             DHFDP= 9.1417257E-14* 11.47287* P**10.47287
           RETURN
      ENDIF
      RETURN
      END

       FUNCTION DHFDPT(P,T)
C Ver. 1.02
****   This function calculates d h/dP |T for light water 
****   in the subcooled liquid phase. 
      PS=PSAT(T)
      DHFDPT = 1.4-169./(369.-T)
      RETURN
      END

       FUNCTION DHFDTP(P,T)
C Ver. 1.02
****   This function calculates d h/dT |P for light water 
****   in the subcooled liquid phase. 
      PS=PSAT(T)
      DHFDTP = -169./(369.-T)**2 * (P-PS)  + 
     *           DPDT(T) * (  DHFDP(PS) - 1.4 + 169./(369.0 - T) )
      RETURN
      END

      FUNCTION DHGDP(P)
C Ver. 1.03
****   This function calculates the derivative with respect to
****   pressure of the specific enthalpy of light water in the gas
****   phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
             DHGDP= 529.44008 * 0.108652 * 0.002**(0.108652-1.0)
             ERRH2O=' DHGDP: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
           DHGDP= -22.92521*2.0* (21.5-18.0) +44.23671
           ERRH2O=' DHGDP: PRESSURE GREATER THAN 21.55 MPa       '
           RETURN
      ELSEIF(P.GE.0.002 .AND. P.LT.0.1379) THEN
           DHGDP= 529.44008 * 0.108652 * P**(0.108652-1.0)
           RETURN
      ELSEIF (P.GE.0.1379.AND.P.LE.0.348) THEN
           DHGDP= 4.0381938E-6*15.72364* (3.0-P)**14.72364
           RETURN
      ELSEIF (P.GT.0.348.AND.P.LE.1.248) THEN
           DHGDP= 0.5767304*1.66153* EXP(-1.66153* (P-3.2))
           RETURN
      ELSEIF (P.GT.1.248.AND.P.LT.2.955) THEN
             DHGDP= 7.835986*2.0* (3.001-P) -2.934312
           RETURN
      ELSEIF (P.GE.2.955.AND.P.LE.6.522) THEN
             DHGDP= -1.347244*2.0* (P-2.999) -2.326913
           RETURN
      ELSEIF (P.GT.6.522.AND.P.LT.16.497) THEN
             DHGDP= -0.9219176*2.0* (P-9.0) -16.38835
           RETURN
      ELSEIF (P.GE.16.497.AND.P.LT.20.193) THEN
             DHGDP= -3.532177*2.0* (P-8.0) +29.81305
           RETURN
      ELSE
             DHGDP= -22.92521*2.0* (P-18.0) +44.23671
           RETURN
      ENDIF

      RETURN
      END

       FUNCTION DHGDPT(P,T)
C Ver. 1.02
****   This function calculates dh/dP |T for light water 
****   in the superheated gaseous phase. 
      TS=TSAT(P)
      PS=PSAT(T)
      PTEMP=P
      P = P + 0.13 * (PS-P)
      DHGDPT = DHGDP(P) -(4.5*P/SQRT(7.4529E-06*T**3-P*P)+0.28* 
     * EXP(-0.008*(T-162))-100/T+2.225)*DTDP(P) +
     * (T-TS) * (4.5/SQRT(7.4529E-06*T**3-P*P) + 
     *          (4.5*P*P/(7.4529E-06*T**3-P*P)**1.5))
      P=PTEMP
      RETURN
      END

       FUNCTION DHGDTP(P,T)
C Ver. 1.02
****   This function calculates dh/dT |P for light water 
****   in the superheated gaseous phase. 
      TS=TSAT(P)
      DHGDTP = +(4.5*P/SQRT(7.4529E-06*T**3-P*P)+0.28* 
     *        EXP(-0.008*(T-162))-100/T+2.225) +
     *        (-(4.5*P/(7.4529E-06*T**3-P*P)**1.5)*1.5*T*T*7.4529E-06 
     *        - 0.28*0.008*EXP(-0.008*(T-162))+100/T/T )*(T-TS) 
      RETURN
      END

      FUNCTION DPDT(T)
C Ver. 1.03
****   This function calculates dP/dT along the saturation line
****   for a given temperature.
C Tmin = 18.0, Tmax = 373.0 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (T .LT. 18.0) THEN
           DPDT=7.406365/270.121*((18.0 + 99.2)/270.121)**
     *            (7.406365-1.)
           RETURN
           ERRH2O=' DPDT: TEMPERATURE LESS THAN 18.0 deg C    '
      ELSEIF (T .GT. 373.0) THEN
           DPDT=4.960785/227.2963*((373.0 + 50.0)/227.2963)**
     *            (4.960785-1.)
           ERRH2O=' DPDT: TEMPERATURE GREATER THAN 373.0 deg C'
           RETURN
      ELSEIF(T .GE. 18.0 .AND. P .LT. 56.275) THEN
           DPDT=7.406365/270.121*((T+99.2)/270.121)**(7.406365-1.)
           RETURN
      ELSEIF(T.GE.56.275 .AND. P.LT.90.88) THEN
           DPDT=6.4058216/254.6831*((T+78.2)/254.6831)**
     *            (6.4058216-1.)
           RETURN
      ELSEIF (T.GE.90.88.AND.T.LT.139.781) THEN
             DPDT=5.602972/236.2315*((T+57.0)/236.2315)**(5.602972-1.)
           RETURN
      ELSEIF (T.GE.139.781.AND.T.LT.203.662) THEN
             DPDT=4.778504/207.9248*((T+28.0)/207.9248)**(4.778504-1.)
           RETURN
      ELSEIF (T.GE.203.662.AND.T.LE.299.407) THEN
             DPDT=4.304376/185.0779*((T+5.0)/185.0779)**(4.304376-1.)
           RETURN
      ELSEIF (T.GT.299.407.AND.T.LT.355.636) THEN
             DPDT=4.460843/195.1819*((T+16.0)/195.1819)**(4.460843-1.)
           RETURN
      ELSE
             DPDT=4.960785/227.2963*((T+50.0)/227.2963)**(4.960785-1.)
           RETURN
      ENDIF
      RETURN
      END

       FUNCTION DRFDPT(P,T)
C Ver. 1.02
****   This function calculates dRHO/dP |T for light water 
****   in the subcooled liquid phase. 
      PS=PSAT(T)
      DRFDPT =  170.0 / (375.0-T) - 0.2 
      RETURN
      END

       FUNCTION DRFDTP(P,T)
C Ver. 1.02
****   This function calculates dRHO/dT |P for light water 
****   in the subcooled liquid phase. 
      PS=PSAT(T)
      DRFDTP = ( 170.0/(375.0-T)**2 ) * (P-PS) +
     *     DPDT(T) * ( -DF(PS)**2 * DVFDP(PS) - 170./(375.0-T) + .2)
      RETURN
      END

       FUNCTION DRGDPT(P,T)
C Ver. 1.02
****   This function calculates d RHO/dP |T for light water 
****   in the superheated gaseous phase. 
      TS=TSAT(P)
      DVGDPT = DVGDP(P)-(0.000466/P-(0.12 / (T+100) - 0.00106 )*P**0.1
     *        / SQRT ( 1.96E-08 * (T+8. )**4 -P*P)) * DTDP(P) +
     *  (-0.000466/P/P -( 0.12 / (T+100) - 0.00106 )*0.1*P**(0.1-1.0)
     *        / SQRT ( 1.96E-08 * (T+8.)**4 -P*P) - ((0.12 / (T+100) - 
     *  0.00106)*P**1.1/ ( 1.96E-08 * (T+8. )**4 -P*P)**1.5)) * (T-TS)
       DRGDPT=-DGSUP(P,T)**2 * DVGDPT
       RETURN
       END

       FUNCTION DRGDTP(P,T)
C Ver. 1.02
****   This function calculates d RHO/dT |P for light water 
****   in the superheated gaseous phase. 
      TS=TSAT(P)
      DVGDTP =  0.000466/P-( 0.12 / (T+100) - 0.00106 )*P**0.1
     *        / SQRT ( 1.96E-08 * (T+8. )**4 -P*P) + (T-TS)*
     *        ( ( 0.12 / (T+100)**2 )*P**0.1
     *        / SQRT ( 1.96E-08 * (T+8. )**4 -P*P) + ( 0.12 / (T+100) 
     *       - 0.00106 )*P**0.1 / ( 1.96E-08 * (T+8. )**4 -P*P)**1.5
     *        /2 * 1.96E-08 * 4.0 * (T+8. )**3)
      DRGDTP=-DGSUP(P,T)**2 * DVGDTP
      RETURN
      END

      FUNCTION DSFDP(P)
C Ver. 1.03
****   This function calculates the derivative with respect to
****   pressure of the specific entropy of light water in the
****   liquid phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P .LT. 0.002) THEN
           DSFDP = 4.5397665*0.0829772*0.002**(0.0829772-1.0)
           ERRH2O = ' DSFDP: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GE. 21.5) THEN
           DSFDP=4.3632383E-05*3.153273*(21.5-0.40)**(3.153273-1.0)
           ERRH2O = ' DSFDP: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF(P.GE.0.002 .AND. P.LT.0.0812) THEN
           DSFDP = 4.5397665 * 0.0829772 * P**(0.0829772-1.0)
           RETURN
      ELSEIF (P.GE.0.0812.AND.P.LT.1.666) THEN
             DSFDP = 3.340244 * 0.125474 * P**(0.125474-1.0)
           RETURN
      ELSEIF (P.GE.1.666.AND.P.LT.8.825) THEN
             DSFDP = 1.748203 * 0.2275611 * P**(0.2275611-1.0)
           RETURN
      ELSEIF (P.GE.8.825.AND.P.LT.16.66) THEN
             DSFDP = 0.2549248 * 0.6381866 * P**(0.6381866-1.0)
           RETURN
      ELSE
             DSFDP = 4.3632383E-05 * 3.153273 * (P-0.40)**(2.153273)
           RETURN
      ENDIF
      RETURN
      END

       FUNCTION DSFDPT(P,T)
C Ver. 1.02
****   This function calculates d s/d P |T for light water 
****   in the subcooled liquid phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      PS=PSAT(T)
      PP=P
      TT=T
       IF (P.LT.PS) THEN
           PP=PS
           ERRH2O=' SFSUB: PRESSURE LESS THAN SATURATION'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' SFSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.89.96) THEN
           TT=89.96
           ERRH2O=' SFSUB: TEMPERATURE LESS THAN 89.96 deg C'
       ELSEIF (T.GT.357.03) THEN
           TT=357.03
           ERRH2O=' SFSUB: TEMPERATURE GREATER THAN 357.03 deg C'
      ENDIF
      DSFDPT = 0.0004-0.325/(370.0-TT)
      RETURN
      END

       FUNCTION DSFDTP(P,T)
C Ver. 1.02
****   This function calculates ds/dT |P for light water
****   in the subcooled liquid phase.
       PS=PSAT(T)
       DSFDTP = -0.325/(370.0-T)**2 * (P-PS) +
     *           DPDT(T) * (DSFDP(PS) - 0.0004 + 0.325/(370.0-T))
       RETURN
       END

      FUNCTION DSGDP(P)
C Ver. 1.03
****   This function calculates the derivative with respect to
****   pressure of the specific entropy of light water in the gas
****   phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           DSGDP = 16.644669*(-0.0192733)*0.002**(-0.0192733-1.)
           ERRH2O=' DSGDP: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
             DSGDP = -0.042830642 * 1.779526 * (21.5-18.7)**0.779526
           ERRH2O=' DSGDP: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.0916) THEN
           DSGDP = 16.644669*(-0.0192733)*P**(-0.0192733-1.)
           RETURN
      ELSEIF (P.GE.0.0916.AND.P.LE.1.48) THEN
              DSGDP = -0.335924/P
           RETURN
      ELSEIF (P.GT.1.48.AND.P.LE.8.05) THEN
             DSGDP = -1.227644 * 0.2481072 * P**(0.2481072-1.0)
           RETURN
      ELSEIF (P.GT.8.05.AND.P.LE.15.64) THEN
             DSGDP = -0.084638514 * 0.9082161 * P**(0.9082161-1.0)
           RETURN
      ELSEIF (P.GT.15.64.AND.P.LE.20.00) THEN
             DSGDP = -3.6897161E-03 * 2.012466 * (P-7.80)**1.012466
           RETURN
      ELSE
             DSGDP = -0.042830642 * 1.779526 * (P-18.7)**0.779526
           RETURN
      ENDIF
      RETURN
      END

       FUNCTION DSGDPT(P,T)
C Ver. 1.02
****   This function calculates ds/dP |T for light water
****   in the superheated gaseous phase.
       TS=TSAT(P)
       DSGDPT = DSGDP(P)-(0.004*P**1.2/SQRT(3.025E-11*(T+46.0)**5-P*P)     
     *           + 5.0E-05/SQRT(P) - 4.125E-06 * T + 0.0053)*DTDP(P) +
     *           (T-TS)*(0.004 * 1.2*P**0.2/SQRT(3.025E-11*(T+46.0)**5
     *           -P*P) + 0.004*P**2.1/(3.025E-11*(T+46.0)**5-P*P)**1.5
     *     -5.0E-05/2.0/P**1.5)
      RETURN
      END

       FUNCTION DSGDTP(P,T)
C Ver. 1.02
****   This function calculates ds/dT |P for light water
****   in the superheated gaseous phase.
       TS=TSAT(P)
       DSGDTP = 0.004 * P**1.2/SQRT(3.025E-11*(T+46.0)**5-P*P)
     *           + 5.0E-05/SQRT(P) - 4.125E-06*T + 0.0053 +
     *           (-0.004*P**1.2*3.025E-11*5.0*(T+46.0)**4/2.0/
     *           (3.025E-11*(T+46.0)**5-P*P)**1.5 -
     *           4.125E-06) * (T-TS)
      RETURN
      END

      FUNCTION DTDP(P)
C Ver. 1.03
****   This function calculates dT/dP along the saturation line
****   for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P .LT. 0.002) THEN
           DTDP=0.1350197 * 270.121* 0.002**(0.135019 -1.0)
           ERRH2O=' DTDP: PRESSURE LESS THAN 0.002 MPa'
           RETURN
      ELSEIF (P .GT. 21.5) THEN
           DTDP= 0.201581 * 227.2963*21.5**(0.201581 - 1.0)
           ERRH2O=' DTDP: PRESSURE GREATER THAN 21.5 MPa'
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.01672) THEN
           DTDP=0.135019 * 270.121 * P**(0.135019-1.0)
           RETURN
      ELSEIF (P.GE.0.01672 .AND. P.LT.0.0725) THEN
           DTDP=0.156108 * 254.6831 * P**(0.156108-1.0)
           RETURN
      ELSEIF (P.GE.0.0725.AND.P.LE.0.359) THEN
             DTDP=0.1784767 * 236.2315* P**(0.1784767 -1.0)
           RETURN
      ELSEIF (P.GT.0.359.AND.P.LE.1.676) THEN
             DTDP=0.2092705 * 207.9248* P**(0.2092705 -1.0)
           RETURN
      ELSEIF (P.GT.1.676.AND.P.LE.8.511) THEN
             DTDP=0.2323217 * 185.0779* P**(0.2323217 -1.0)
           RETURN
      ELSEIF (P.GT.8.511.AND.P.LE.17.69) THEN
             DTDP=0.2241729 * 195.1819* P**(0.2241729 -1.0)
           RETURN
      ELSE
             DTDP= 0.201581 * 227.2963*P**(0.201581 - 1.0)
           RETURN
      ENDIF
      RETURN
      END

      FUNCTION DVFDP(P)
C Ver. 1.03
****   This function calculates the derivative with respect to
****   pressure of the specific volume of light water in the liquid
****   phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P .LT. 0.002) THEN
           DVFDP=1.9118E-4*0.546472* 0.002**(0.546472-1.0)
           ERRH2O=' DVFDP: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GT. 21.5) THEN
              DVFDP= 4.1035988E-24* 15.03329* 21.5**14.03329
           ERRH2O=' DVFDP: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.01468) THEN
           DVFDP=1.9118E-4 * 0.546472 * P**(0.546472-1.0)
           RETURN
      ELSEIF (P.GE.0.01468 .AND. P.LT.0.275) THEN
           DVFDP=1.380934E-4 * 0.388715 * P**(0.388715-1.0)
           RETURN
      ELSEIF (P.GE.0.275.AND.P.LE.1.0) THEN
           DVFDP=1.2746977E-4*0.4644339* P**(0.4644339-1.0)
           RETURN
      ELSEIF (P.GT.1.0.AND.P.LE.3.88) THEN
             DVFDP=1.0476071E-4*0.5651090* P**(0.5651090 -1.0)
           RETURN
      ELSEIF (P.GT.3.88.AND.P.LE.8.84) THEN
             DVFDP= 3.2836717E-5
           RETURN
      ELSEIF (P.GT.8.84.AND.P.LE.14.463) THEN
             DVFDP=3.3551046E-4*0.058403566* EXP(0.058403566*P)
           RETURN
      ELSEIF (P.GT.14.463.AND.P.LT.18.052) THEN
             DVFDP= 3.1014626E-8* 3.284754* P**2.284754
           RETURN
      ELSEIF (P.GE.18.052.AND.P.LT.20.204) THEN
             DVFDP= 1.5490787E-11* 5.7205* P**4.7205
           RETURN
      ELSE
             DVFDP= 4.1035988E-24* 15.03329* P**14.03329
           RETURN
      ENDIF
      RETURN
      END

      FUNCTION DVGDP(P)
C Ver. 1.03
****   This function calculates the derivative with respect to
****   pressure of the specific volume of light water in the gas
****   phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           DDGDP= 5.0981616 * 0.936226 * 0.002**(0.936226-1.0)
           DVGDP=-1.0*VG(0.002)**2 *DDGDP
           ERRH2O=' DVGDP: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
             DDGDP= 3.558734E-16* 13.03774* 21.5**12.03774
             DVGDP=-1.0*VG(21.5)**2 *DDGDP
             ERRH2O=' DVGDP: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.2139) THEN
           DDGDP= 5.0981616 * 0.936226 * P**(0.936226-1.0)
           DVGDP=-1.0 * VG(P)**2 * DDGDP
           RETURN
      ELSEIF (P.GE.0.2139.AND.P.LT.1.112) THEN
              DDGDP= 5.126076*0.9475862* P**(0.9475862 -1.0)
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ELSEIF (P.GE.1.112.AND.P.LT.3.932) THEN
             DDGDP= 4.630832*1.038819* P**0.038819
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ELSEIF (P.GE.3.932.AND.P.LT.8.996) THEN
             DDGDP= 2.868721*1.252148* P**0.252148
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ELSEIF (P.GE.8.996.AND.P.LT.14.628) THEN
             DDGDP= 0.5497653*1.831182* P**0.831182
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ELSEIF (P.GE.14.628.AND.P.LE.18.21) THEN
             DDGDP= 8.5791582E-3* 3.176484* P**2.176484
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ELSEIF (P.GT.18.21.AND.P.LE.20.253) THEN
             DDGDP= 3.5587113E-6* 5.660939* P**4.660939
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ELSE
             DDGDP= 3.558734E-16* 13.03774* P**12.03774
             DVGDP=-1.0*VG(P)**2 *DDGDP
           RETURN
      ENDIF
      RETURN
      END

      FUNCTION HF(P)
C Ver. 1.03
****   This function calculates the specific enthalpy of light water
****   in the liquid phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           HF= 1128.777 * 0.002**0.135196 - 413.72
           ERRH2O=' HF: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GT. 21.5) THEN
           HF= 9.1417257E-14* 21.5**11.47287 +1752.0
           ERRH2O=' HF: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.0173) THEN
           HF= 1128.777 * P**0.135196 - 413.72
           RETURN
      ELSEIF (P.GE.0.0173 .AND. P.LT.0.1028) THEN
           HF= 1050.7085 * P**0.161797 - 306.5
           RETURN
      ELSEIF (P.GE.0.1028.AND.P.LT.0.942) THEN
             HF= 912.1779* P**0.2061637 -150.0
           RETURN
      ELSEIF (P.GE.0.942.AND.P.LT.4.02) THEN
             HF= 638.0621* P**0.2963192 +125.0
           RETURN
      ELSEIF (P.GE.4.02.AND.P.LT.9.964) THEN
             HF= 373.7665* P**0.4235532 +415.0
           RETURN
      ELSEIF (P.GE.9.964.AND.P.LT.16.673) THEN
             HF= 75.38673* P**0.8282384 +900.0
           RETURN
      ELSEIF (P.GE.16.673.AND.P.LT.20.396) THEN
             HF= 0.1150827* P**2.711412 +1440.0
           RETURN
      ELSE
             HF= 9.1417257E-14* P**11.47287 +1752.0
           RETURN
      ENDIF
      RETURN
      END

       FUNCTION HFSUB(P,T)
C Ver. 1.02
****   This function calculates the enthalpy of light water 
****   in the subcooled liquid phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      PP=P
      TT=T
      PS=PSAT(T)
       IF (P.LT.PS) THEN
           PP=PS
           ERRH2O=' HFSUB: PRESSURE LESS THAN SATURATION'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' HFSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.91.79) THEN
           TT=91.79
           ERRH2O=' HFSUB: TEMPERATURE LESS THAN 91.79 deg C'
       ELSEIF (T.GT.357.03) THEN
           TT=357.03
           ERRH2O=' HFSUB: TEMPERATURE GREATER THAN 357.03 deg C'
      ENDIF
      HFSUB = HF(PS) + (1.4-169./(369.-TT))*(PP-PS)
      RETURN
      END

      FUNCTION HG(P)
C Ver. 1.03
****   This function calculates the specific enthalpy of light water
****   in the gas phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           HG= 529.44008 * 0.002**0.108652 + 2263.5
           ERRH2O=' HG: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P .GT. 21.5) THEN
           HG= -22.92521* (21.55-18.0)**2.0 +44.23671* (21.5-18.0) +
     *          2415.01
           ERRH2O=' HG: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.1379) THEN
           HG= 529.44008 * P**0.108652 + 2263.5
           RETURN
      ELSEIF (P.GE.0.1379.AND.P.LE.0.348) THEN
             HG= -4.0381938E-6* (3.0-P)**15.72364 +2750.0
           RETURN
      ELSEIF (P.GT.0.348.AND.P.LE.1.248) THEN
             HG= -0.5767304* EXP(-1.66153* (P-3.2)) +2800.0
           RETURN
      ELSEIF (P.GT.1.248.AND.P.LT.2.955) THEN
             HG= -7.835986* (3.001-P)**2. +2.934312*(3.001-P) +2803.71
           RETURN
      ELSEIF (P.GE.2.955.AND.P.LE.6.522) THEN
             HG=-1.347244*(P-2.999)*(P-2.999)-2.326913*(P-2.999)+2803.35
           RETURN
      ELSEIF (P.GT.6.522.AND.P.LT.16.497) THEN
             HG= -0.9219176* (P-9.0)*(P-9.0) -16.38835*(P-9.0) +2742.03
           RETURN
      ELSEIF (P.GE.16.497.AND.P.LT.20.193) THEN
             HG= -3.532177* (P-8.0)**2.0 +29.81305* (P-8.0) +2565.00
           RETURN
      ELSE
             HG= -22.92521* (P-18.0)**2.0 +44.23671* (P-18.0) +2415.01
           RETURN
      ENDIF
      RETURN
      END

       FUNCTION HGSUP(P,T)
C Ver. 1.02
****   This function calculates the enthalpy of light water 
****   in the superheated gaseous phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      TS=TSAT(P)
      PP=P
      TT=T
       IF (P.LT.0.075) THEN
           PP=0.075
           ERRH2O=' HGSUB: PRESSURE LESS THAN 0.075 MPa'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' HGSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.TS) THEN
           TT=TS
           ERRH2O=' HGSUB: TEMPERATURE LESS THAN SATURATION'
       ELSEIF (T.GT.450.) THEN
           TT=450.
           ERRH2O=' HGSUB: TEMPERATURE GREATER THAN 450. deg C'
      ENDIF
      HGSUP = HG(PP) +(4.5*PP/SQRT(7.4529E-06*TT**3-PP*PP)+0.28* 
     *        EXP(-0.008*(TT-162))-100/TT+2.225)*(TT-TS) 
      RETURN
      END

      FUNCTION PSAT(T)
C Ver. 1.03
****   This function calculates the saturation pressure of light water
****   for a given temperature.
C Tmin = 18.0, Tmax = 373.0 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (T .LT. 18.0) THEN
           PSAT=((18.0 + 99.2)/270.121)**7.406365
           ERRH2O=' PSAT: TEMPERATURE LESS THAN 18.0 deg C    '
           RETURN
      ELSEIF (T .GT. 373.0) THEN
              PSAT=((373.0+50.0)/227.2963)**4.960785
           ERRH2O=' PSAT: TEMPERATURE GREATER THAN 373.0 deg C '
           RETURN
      ELSEIF (T.GE.18.0 .AND. T.LT.56.275) THEN
           PSAT=((T+99.2)/270.121)**7.406365
           RETURN
      ELSEIF (T.GE.56.275 .AND. T.LT.90.88) THEN
           PSAT=((T+78.2)/254.6831)**6.4058216
           RETURN
      ELSEIF (T.GE.90.88.AND.T.LT.139.781) THEN
             PSAT=((T+57.0)/236.2315)**5.602972
           RETURN
      ELSEIF (T.GE.139.781.AND.T.LT.203.662) THEN
             PSAT=((T+28.0)/207.9248)**4.778504
           RETURN
      ELSEIF (T.GE.203.662.AND.T.LE.299.407) THEN
             PSAT=((T+5.0)/185.0779)**4.304376
           RETURN
      ELSEIF (T.GT.299.407.AND.T.LT.355.636) THEN
             PSAT=((T+16.0)/195.1819)**4.460843
           RETURN
      ELSE
             PSAT=((T+50.0)/227.2963)**4.960785
           RETURN
      ENDIF
      RETURN
      END

      FUNCTION SF(P)
C Ver. 1.03
****   This function calculates the specific entropy of light water
****   in liquid phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           SF=4.5397665 * 0.002**0.0829772 - 2.449
           ERRH2O=' SF: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
             SF=4.3632383E-5*(21.25-0.40)**(3.153273)+3.5
           ERRH2O=' SF: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.0812) THEN
           SF=4.5397665 * P**0.0829772 - 2.449
           RETURN
      ELSEIF (P.GE.0.0812.AND.P.LT.1.666) THEN
             SF=3.340244*P**(0.125474)-1.2
           RETURN
      ELSEIF (P.GE.1.666.AND.P.LT.8.825) THEN
             SF=1.748203*P**(0.2275611)+0.4
           RETURN
      ELSEIF (P.GE.8.825.AND.P.LT.16.66) THEN
             SF=0.2549248*P**(0.6381866)+2.25
           RETURN
      ELSE
             SF=4.3632383E-5*(P-0.40)**(3.153273)+3.5
           RETURN
      ENDIF
C      ERRH2O=' SF: ENTROPY OF SUBCOOLED LIQUID NOT EVALUATED'
      RETURN
      END

       FUNCTION SFSUB(P,T)
C Ver. 1.02
****   This function calculates the entropy of light water 
****   in the subcooled liquid phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      PS=PSAT(T)
      PP=P
      TT=T
       IF (P.LT.PS) THEN
           PP=PS
           ERRH2O=' SFSUB: PRESSURE LESS THAN SATURATION'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' SFSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.89.96) THEN
           TT=89.96
           ERRH2O=' SFSUB: TEMPERATURE LESS THAN 89.96 deg C'
       ELSEIF (T.GT.357.03) THEN
           TT=357.03
           ERRH2O=' SFSUB: TEMPERATURE GREATER THAN 357.03 deg C'
      ENDIF
      SFSUB = SF(PS) + (0.0004-0.325/(370.0-TT))*(PP-PS)
      RETURN
      END

      FUNCTION SG(P)
C Ver. 1.03
****   This function calculates the specific entropy of light water
****   in vapour phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           SG=16.644669 * 0.002**(-0.0192733) - 10.039
           ERRH2O=' SG: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
           SG= 5.0-0.042830642*(21.55-18.7)**(1.779526)
           ERRH2O=' SG: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.0916) THEN
           SG=16.644669 * P**(-0.0192733) - 10.039
           RETURN
      ELSEIF (P.GE.0.0916.AND.P.LE.1.48) THEN
             SG=6.58681-0.335924*ALOG(P)
           RETURN
      ELSEIF (P.GT.1.48.AND.P.LE.8.05) THEN
             SG=7.8-1.227644*P**(0.2481072)
           RETURN
      ELSEIF (P.GT.8.05.AND.P.LE.15.64) THEN
             SG=6.3-0.084638514*P**(0.9082161)
           RETURN
      ELSEIF (P.GT.15.64.AND.P.LE.20.0) THEN
             SG=5.5-3.6897161E-3*(P-7.8)**(2.012466)
           RETURN
      ELSE
             SG= 5.0-0.042830642*(P-18.7)**(1.779526)
           RETURN
      ENDIF
C      ERRH2O=' SG: ENTROPY OF SUPERHEATED GAS NOT EVALUATED'
      RETURN
      END

       FUNCTION SGSUP(P,T)
C Ver. 1.02
****   This function calculates the entropy of light water 
****   in the superheated gaseous phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      TS=TSAT(P)
      PP=P
      TT=T
       IF (P.LT.0.07) THEN
           PP=0.07
           ERRH2O=' SGSUB: PRESSURE LESS THAN 0.07 MPa'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' SGSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.TS) THEN
           TT=TS
           ERRH2O=' SGSUB: TEMPERATURE LESS THAN SATURATION'
       ELSEIF (T.GT.450.) THEN
           TT=450.
           ERRH2O=' SGSUB: TEMPERATURE GREATER THAN 450. deg C'
      ENDIF
      SGSUP = SG(PP)+(0.004*PP**1.2/SQRT(3.025E-11*(TT+46)**5-PP*PP)+    
     *         0.00005/SQRT(PP)-4.125E-6*TT+0.0053) * ( TT-TS )
      RETURN
      END

      FUNCTION TSAT(P)
C Ver. 1.03
****   This function calculates the saturation temperature of light water
****   for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           TSAT=270.121* .002**0.135019 - 99.2
           ERRH2O=' TSAT: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
           TSAT= 227.2963*21.5**0.201581 - 50.0
           ERRH2O=' TSAT: PRESSURE GREATER THAN 21.5           '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.01672) THEN
           TSAT=270.121 * P**0.135019 - 99.2
           RETURN
      ELSEIF (P.GE.0.01672 .AND. P.LT.0.0725) THEN
           TSAT=254.6831 * P**0.156108 - 78.2
           RETURN
      ELSEIF (P.GE.0.0725.AND.P.LE.0.359) THEN
             TSAT=236.2315* P**0.1784767 -57.0
           RETURN
      ELSEIF (P.GT.0.359.AND.P.LE.1.676) THEN
             TSAT=207.9248* P**0.2092705 -28.0
           RETURN
      ELSEIF (P.GT.1.676.AND.P.LE.8.511) THEN
             TSAT=185.0779* P**0.2323217 -5.0
           RETURN
      ELSEIF (P.GT.8.511.AND.P.LE.17.69) THEN
             TSAT=195.1819* P**0.2241729 - 16.0
           RETURN
      ELSE
             TSAT= 227.2963*P**0.201581 - 50.0
           RETURN
      ENDIF
C      ERRH2O=' TSAT: SATURATION TEMPERATURE NOT EVALUATED'
      RETURN
      END

      FUNCTION VF(P)
C Ver. 1.03
****   This function calculates the specific volume of light water
****   in liquid phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           VF=1.9118E-4 * 0.002**0.546472 + 0.0009947
           ERRH2O=' VF: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
             VF= 4.1035988E-24* 21.5**15.03329 +0.00189
             ERRH2O=' VF: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.01468) THEN
           VF=1.9118E-4 * P**0.546472 + 0.0009947
           RETURN
      ELSEIF (P.GE.0.01468 .AND. P.LT.0.275) THEN
           VF=1.380934E-4 * P**0.388715 + 0.000987
           RETURN
      ELSEIF (P.GE.0.275.AND.P.LE.1.0) THEN
              VF=1.2746977E-4* P**0.4644339 +0.001
           RETURN
      ELSEIF (P.GT.1.0.AND.P.LE.3.88) THEN
             VF=1.0476071E-4* P**0.5651090 +0.001022
           RETURN
      ELSEIF (P.GT.3.88.AND.P.LE.8.84) THEN
             VF=3.2836717E-5* P +1.12174735E-3
           RETURN
      ELSEIF (P.GT.8.84.AND.P.LE.14.463) THEN
             VF=3.3551046E-4 * EXP(0.058403566 *P) +0.00085
           RETURN
      ELSEIF (P.GT.14.463.AND.P.LT.18.052) THEN
           VF= 3.1014626E-8* P**3.284754 +0.00143
           RETURN
      ELSEIF (P.GE.18.052.AND.P.LT.20.204) THEN
             VF= 1.5490787E-11* P**5.7205 +0.001605
           RETURN
      ELSE
             VF= 4.1035988E-24* P**15.03329 +0.00189
           RETURN
      ENDIF
C      ERRH2O=' VF: VOLUME OF SUBCOOLED LIQUID NOT EVALUATED'
      RETURN
      END

       FUNCTION VFSUB(P,T)
C Ver. 1.02
****   This function calculates the specific volume of light water 
****   in the subcooled liquid phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      PS=PSAT(T)
      PP=P
      TT=T
       IF (P.LT.PS) THEN
           PP=PS
           ERRH2O=' VFSUB: PRESSURE LESS THAN SATURATION'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' VFSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.91.79) THEN
           TT=91.79
           ERRH2O=' VFSUB: TEMPERATURE LESS THAN 91.79 deg C'
       ELSEIF (T.GT.357.03) THEN
           TT=357.03
           ERRH2O=' VFSUB: TEMPERATURE GREATER THAN 357.03 deg C'
      ENDIF
      VFSUB = (DF(PS) + ( 170.0 / (375.0-TT) - 0.2) * ( PP-PS ))**(-1)
      RETURN
      END

      FUNCTION VG(P)
C Ver. 1.03
****   This function calculates the specific volume of light water
****   in the gas phase at saturation for a given pressure.
C Pmin = 0.002, Pmax = 21.5 MPa
C Low pressure region provided by Bartak et al 90.22.03

      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      IF (P.LT.0.002) THEN
           VG= 1.0/(5.0981616 * 0.002**0.936226 - 0.00025)
           ERRH2O=' VG: PRESSURE LESS THAN 0.002 MPa    '
           RETURN
      ELSEIF (P.GT.21.5) THEN
             VG= 1.0/( 3.558734E-16* 21.5**13.03774 +138.0)
             ERRH2O=' VG: PRESSURE GREATER THAN 21.5 MPa       '
           RETURN
      ELSEIF (P.GE.0.002 .AND. P.LT.0.2139) THEN
             VG= 1.0/ (5.0981616 * P**0.936226 - 0.00025)
           RETURN
      ELSEIF (P.GE.0.2139.AND.P.LT.1.112) THEN
              VG= 1.0/(5.126076* P**0.9475862 +0.012)
              RETURN
      ELSEIF (P.GE.1.112.AND.P.LT.3.932) THEN
             VG= 1.0/(4.630832* P**1.038819 +0.52)
           RETURN
      ELSEIF (P.GE.3.932.AND.P.LT.8.996) THEN
             VG= 1.0/(2.868721* P**1.252148 +3.80)
           RETURN
      ELSEIF (P.GE.8.996.AND.P.LT.14.628) THEN
           VG= 1.0/(0.5497653* P**1.831182 +18.111)
           RETURN
      ELSEIF (P.GE.14.628.AND.P.LE.18.21) THEN
             VG=1.0/(8.5791582E-3* P**3.176484 +50.0)
           RETURN
      ELSEIF (P.GT.18.21.AND.P.LE.20.253) THEN
             VG= 1.0/( 3.5587113E-6* P**5.660939 +88.0)
           RETURN
      ELSE
             VG= 1.0/( 3.558734E-16* P**13.03774 +138.0)
           RETURN
      ENDIF
C      ERRH2O=' VG: VOLUME OF SUPERHEATED GAS NOT EVALUATED'
      RETURN
      END


       FUNCTION VGSUP(P,T)
C Ver. 1.02
****   This function calculates the density of light water 
****   in the superheated gaseous phase. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
      TS=TSAT(P)
      PP=P
      TT=T
       IF (P.LT.0.085) THEN
           PP=0.085
           ERRH2O=' VGSUB: PRESSURE LESS THAN 0.085 MPa'
      ELSEIF (P.GT.18.) THEN
           PP=18.
           ERRH2O=' VGSUB: PRESSURE GREATER THAN 18 MPa'
       ELSEIF (T.LT.TS) THEN
           TT=TS
           ERRH2O=' VGSUB: TEMPERATURE LESS THAN SATURATION'
       ELSEIF (T.GT.450.) THEN
           TT=450.
           ERRH2O=' VGSUB: TEMPERATURE GREATER THAN 450. deg C'
      ENDIF
      VGSUP = VG(PP)+(0.000466/P-( 0.12 / (TT+100) - 0.00106 )*PP**0.1
     *        / SQRT ( 1.96E-08 * (TT+8. )**4 -PP*PP)) * (TT-TS)
      RETURN
      END

       FUNCTION VISCF(P)
C Ver. 1.02
****   This function calculates the viscosity of light water 
****   in the liquid phase at saturation for a given pressure. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
       IF (P.LT.0.035) THEN
             VISCF= 111.5993* 0.035**(-0.3425488) +38.0
           ERRH2O=' VISCF: PRESSURE LESS THAN 0.035 MPa'
           RETURN
      ELSEIF (P.GT.21.45) THEN
             VISCF= 64.0 -0.00261596*EXP(0.4010038*21.45)
           ERRH2O=' VISCF: PRESSURE GREATER THAN 21.45 MPa'
             RETURN
          ELSEIF (P.GE.0.035.AND.P.LT.0.960) THEN
             VISCF= 111.5993* P**(-0.3425488) +38.0
             RETURN
          ELSEIF (P.GE.0.960.AND.P.LE.3.948) THEN
             VISCF= 134.5288* P**(-0.2848300) +15.0
             RETURN
          ELSEIF (P.GT.3.948.AND.P.LT.9.514) THEN
             VISCF= 141.5415 -25.91353*ALOG(P)
             RETURN
          ELSEIF (P.GE.9.514.AND.P.LT.15.074) THEN
             VISCF= 113.4599* EXP(-0.03279562*P)
             RETURN
          ELSEIF (P.GE.15.074.AND.P.LT.18.868) THEN
             VISCF= 110.0 -17.67922*EXP(0.05556056*P)
             RETURN
          ELSEIF (P.GE.18.868.AND.P.LT.20.430) THEN
             VISCF= 9.12152*P -0.3159837*P**2.0
             RETURN
          ELSE
             VISCF= 64.0 -0.00261596*EXP(0.4010038*P)
             RETURN
       ENDIF
       END

       FUNCTION VISCG(P)
C Ver. 1.02
****   This function calculates the viscosity of light water 
****   in the vapour phase at saturation for a given pressure. 
      CHARACTER ERRH2O*70
      COMMON/ERRORS/ERRH2O
       IF (P.LT.0.04) THEN
             VISCG= 7.473620* 0.04**(0.2050149) +7.6
           ERRH2O=' VISCG: PRESSURE LESS THAN 0.04 MPa'
           RETURN
      ELSEIF (P.GT.21.35) THEN
             VISCG= 6.6753655E-6* EXP(0.6347700*21.35) +25.1
           ERRH2O=' VISCG: PRESSURE GREATER THAN 21.35 MPa'
             RETURN
          ELSEIF (P.GE.0.040.AND.P.LE.2.207) THEN
             VISCG= 7.473620* P**(0.2050149) +7.6
             RETURN
          ELSEIF (P.GT.2.207.AND.P.LE.5.480) THEN
             VISCG= 3.375163* P**(0.3916208) +11.8
             RETURN
          ELSEIF (P.GT.5.480.AND.P.LT.9.585) THEN
             VISCG= 0.9169410* P**(0.7644731) +15.0
             RETURN
          ELSEIF (P.GE.9.585.AND.P.LT.14.351) THEN
             VISCG= 5.030544* EXP(0.05045239*P) +12.0
             RETURN
          ELSEIF (P.GE.14.351.AND.P.LT.18.385) THEN
             VISCG= 0.4423761*EXP(0.1458726*P) +18.8
             RETURN
          ELSEIF (P.GE.18.385.AND.P.LE.20.347) THEN
             VISCG= 0.01082229* EXP(0.3071918*P) +22.2
             RETURN
          ELSE
             VISCG= 6.6753655E-6* EXP(0.6347700*P) +25.1
             RETURN
       ENDIF
       END
